@@ -32,15 +32,15 @@ import frozendict  # noqa: F401
 
 from groundx import schemas  # noqa: F401
 
-from groundx.model.bucket_detail import BucketDetail as BucketDetailSchema
+from groundx.model.bucket_update_response import BucketUpdateResponse as BucketUpdateResponseSchema
+from groundx.model.bucket_update_detail import BucketUpdateDetail as BucketUpdateDetailSchema
 from groundx.model.bucket_update_request_bucket import BucketUpdateRequestBucket as BucketUpdateRequestBucketSchema
 from groundx.model.bucket_update_request import BucketUpdateRequest as BucketUpdateRequestSchema
-from groundx.model.bucket_response import BucketResponse as BucketResponseSchema
 
+from groundx.type.bucket_update_detail import BucketUpdateDetail
 from groundx.type.bucket_update_request import BucketUpdateRequest
-from groundx.type.bucket_response import BucketResponse
+from groundx.type.bucket_update_response import BucketUpdateResponse
 from groundx.type.bucket_update_request_bucket import BucketUpdateRequestBucket
-from groundx.type.bucket_detail import BucketDetail
 
 from . import path
 
@@ -84,17 +84,17 @@ request_body_bucket_update_request = api_client.RequestBody(
 _auth = [
     'ApiKeyAuth',
 ]
-SchemaFor200ResponseBodyApplicationJson = BucketResponseSchema
+SchemaFor200ResponseBodyApplicationJson = BucketUpdateResponseSchema
 
 
 @dataclass
 class ApiResponseFor200(api_client.ApiResponse):
-    body: BucketResponse
+    body: BucketUpdateResponse
 
 
 @dataclass
 class ApiResponseFor200Async(api_client.AsyncApiResponse):
-    body: BucketResponse
+    body: BucketUpdateResponse
 
 
 _response_for_200 = api_client.OpenApiResponse(
